pycdf.lib - Access to CDF library — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- homepage|
- search|
- documentation »

# pycdf.lib - Access to CDF library

`spacepy.pycdf.` `lib`

Module global `Library` object.

Initalized at `pycdf` load time so all classes have ready access to the CDF library and a common state. E.g:

    >>> from spacepy import pycdf
    >>> pycdf.lib.version
        (3, 3, 0, ' ')

### Navigation

- index
- modules |
- modules |
- homepage|
- search|
- documentation »